%
% This code accompanies the paper:
%
% "Anisotropic Diffusion Descriptors"
% D.Boscaini, J.Masci, E.Rodola, M.Bronstein, D.Cremers
% CGF 35(2), 2016
%
% Please cite the paper above if you use this code in your research.
%
% Emanuele Rodola <emanuele.rodola@usi.ch>
% USI Lugano, 2016
%
clc
close all
clear all

addpath('./curvature/')
addpath('./tools/')
addpath('./aniso/')

M = load_off('./data/tr_reg_000.off');

options = struct;
options.curv_smooth = 10;
options.n_eigen = 300;
options.alpha = 300; % alpha=0 gives isotropic Laplacian

time = 5e-3;
% source = 4394; % thigh
source = 4168; % hip

angles = 90:10:130;
kernels = cell(1,length(angles));

figure, colormap(bluemap())

for k=1:length(angles)
    
    options.angle = pi*angles(k)/180;
    [evecs, evals, W, A] = calc_ALB(M.VERT, M.TRIV, options);
    
    kernels{k} = (evecs.*(repmat(evecs(source,:),[size(evecs,1) 1])))*exp(-time*evals);
    
    subplot(1,length(angles),k)
    
    trisurf(M.TRIV,M.VERT(:,1),M.VERT(:,2),M.VERT(:,3),kernels{k},'SpecularStrength',0.15); 
    l = light; 
    set(l,'Position',[0 1 5])
    lighting phong;
    axis equal; shading interp; axis off;
    rotate3d on
    view([0 90])
    title(sprintf('angle: %.1f',angles(k)))
    
end
